@@ -4,6 +4,7 @@ import time
 from enum import Enum
 
 import kubernetes
+
 from dagster import DagsterInstance, check
 from dagster.core.storage.pipeline_run import PipelineRunStatus
 
@@ -121,6 +122,7 @@ class KubernetesWaitingReasons:
     ImagePullBackOff = "ImagePullBackOff"
     CrashLoopBackOff = "CrashLoopBackOff"
     RunContainerError = "RunContainerError"
+    CreateContainerConfigError = "CreateContainerConfigError"
 
 
 class DagsterKubernetesClient:
@@ -314,13 +316,13 @@ class DagsterKubernetesClient:
             errors = []
             try:
                 self.batch_api.delete_namespaced_job(name=job_name, namespace=namespace)
-            except Exception as e:  # pylint: disable=broad-except
+            except Exception as e:
                 errors.append(e)
 
             for pod_name in pod_names:
                 try:
                     self.core_api.delete_namespaced_pod(name=pod_name, namespace=namespace)
-                except Exception as e:  # pylint: disable=broad-except
+                except Exception as e:
                     errors.append(e)
 
             if len(errors) > 0:
@@ -341,6 +343,23 @@ class DagsterKubernetesClient:
 
     ### Pod operations ###
 
+    def get_pods_in_job(self, job_name, namespace):
+        """Get the pods launched by the job ``job_name``.
+
+        Args:
+            job_name (str): Name of the job to inspect.
+            namespace (str): Namespace in which the job is located.
+
+        Returns:
+            List[V1Pod]: List of all pod objects that have been launched by the job ``job_name``.
+        """
+        check.str_param(job_name, "job_name")
+        check.str_param(namespace, "namespace")
+
+        return self.core_api.list_namespaced_pod(
+            namespace=namespace, label_selector="job-name={}".format(job_name)
+        ).items
+
     def get_pod_names_in_job(self, job_name, namespace):
         """Get the names of pods launched by the job ``job_name``.
 
@@ -354,9 +373,7 @@ class DagsterKubernetesClient:
         check.str_param(job_name, "job_name")
         check.str_param(namespace, "namespace")
 
-        pods = self.core_api.list_namespaced_pod(
-            namespace=namespace, label_selector="job-name={}".format(job_name)
-        ).items
+        pods = self.get_pods_in_job(job_name, namespace)
         return [p.metadata.name for p in pods]
 
     def wait_for_pod(
@@ -445,6 +462,13 @@ class DagsterKubernetesClient:
                     self.logger('Waiting for pod "%s" to initialize...' % pod_name)
                     self.sleeper(wait_time_between_attempts)
                     continue
+                if state.waiting.reason == KubernetesWaitingReasons.CreateContainerConfigError:
+                    self.logger(
+                        'Pod "%s" is waiting due to a CreateContainerConfigError with message "%s" - trying again to see if it recovers'
+                        % (pod_name, state.waiting.message)
+                    )
+                    self.sleeper(wait_time_between_attempts)
+                    continue
                 elif state.waiting.reason == KubernetesWaitingReasons.ContainerCreating:
                     self.logger("Waiting for container creation...")
                     self.sleeper(wait_time_between_attempts)
